<?php

namespace Concrete\Package\JlContainerCheck;

defined('C5_EXECUTE') or die('Access Denied.');

use Concrete\Core\Package\Package;
use Concrete\Core\Page\Page;
use Concrete\Core\Page\Single as SinglePage;

/*
 * John Liddiard (aka JohntheFish) www.c5magic.co.uk
 * This package contains software copyright and proprietary to John Liddiard
 *
 */

class Controller extends Package {

    protected $pkgHandle = 'jl_container_check';
    protected $appVersionRequired = '9.0.2';
    protected $pkgVersion = '9.0.2';

    /*
     * v1.0.0 - php8 compatibility
     * v9.0.0 - Checks for looped areas. Integration with Container Magic.
     * v9.0.1 - Extra defence against missing or broken containers.
     * v9.0.2 - Update to support container magic enhancement.
     */

    protected $pkgAutoloaderRegistries = [
        'src/ContainerCheck' => '\ContainerCheck',
    ];

    public function getPackageDescription() {
        return t('A rough preview of the layouts provided by containers in a concrete CMS theme');
    }

    public function getPackageName() {
        return t('Container Check');
    }

    public function install() {
        $pkg = parent::install();
        $this->do_install($pkg);
    }

    public function upgrade() {
        parent::upgrade();
        $this->do_install($this);
    }

    private function do_install($pkg) {
        $this->install_pages($pkg);
    }

    /*
     * Install dashboard pages
     */
    private function install_pages($pkg)
    {
        $dashboard_pages = $this->list_dashboard_pages($pkg);
        foreach ($dashboard_pages as $path => $page_setup) {
            $page = Page::getByPath($path);
            if (!is_object($page) || $page->isError()) {
                $name = $page_setup['cName'];
                $description = $page_setup['cDescription'];
                $page = SinglePage::add($path, $pkg);
                $page->update(['cName' => $name, 'cDescription' => $description]);
            }
            $page->refreshCache();
        }
    }


    public function list_dashboard_pages($pkg)
    {
        $dashboard_pages = [
            '/dashboard/pages/container_check'
            => [
                'cName' => $pkg->getPackageName(),
                'cDescription' => $pkg->getPackageDescription(),
            ]
        ];
        return $dashboard_pages;
    }


}
